@@ -22,7 +22,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 """
 
-__version__ = "0.3.37"
+__version__ = "0.3.38"
 __author__ = "nagev"
 __license__ = "GPLv3"
 
@@ -108,9 +108,9 @@ class g(object):
     """ Class for holding constants needed throughout the module. """
 
     urls = {
-        'gdata': "https://gdata.youtube.com/feeds/api/videos/%s?v=2",
-        'watchv': "https://www.youtube.com/watch?v=%s",
-        'vidinfo': ('https://www.youtube.com/get_video_info?'
+        'gdata': "http://gdata.youtube.com/feeds/api/videos/%s?v=2",
+        'watchv': "http://www.youtube.com/watch?v=%s",
+        'vidinfo': ('http://www.youtube.com/get_video_info?'
                     'video_id=%s&asv=3&el=detailpage&hl=en_US'),
         'playlist': ('http://www.youtube.com/list_ajax?',
                      'style=json&action_get_list=1&list=%s')
@@ -152,6 +152,10 @@ class g(object):
         '140': ('128k', 'm4a', 'audio', ''),
         '141': ('256k', 'm4a', 'audio', ''),
         '160': ('256x144', 'm4v', 'video', ''),
+        '167': ('640x480', 'webm', 'video', ''),
+        '168': ('854x480', 'webm', 'video', ''),
+        '169': ('1280x720', 'webm', 'video', ''),
+        '170': ('1920x1080', 'webm', 'video', ''),
         '171': ('128k', 'ogg', 'audio', ''),
         '172': ('192k', 'ogg', 'audio', ''),
         '242': ('360x240', 'webm', 'normal', ''),
@@ -378,7 +382,6 @@ def get_video_info(video_id):
     """ Return info for video_id.  Returns dict. """
 
     url = g.urls['vidinfo'] % video_id
-    dbg("Fetching video info")
     info = decode_if_py3(g.opener.open(url).read())
     info = parse_qs(info)
     dbg("Fetched video info")
@@ -393,10 +396,12 @@ def get_video_info(video_id):
 def get_video_gdata(video_id):
     """ Return xml string containing video metadata from gdata api. """
 
-    dbg("Fetching gdata info")
+    new.callback("Fetching video gdata")
     url = g.urls['gdata'] % video_id
+    gdata = g.opener.open(g.urls['gdata'] % video_id).read()
     dbg("Fetched video gdata")
-    return g.opener.open(url).read()
+    new.callback("Fetched video gdata")
+    return gdata
 
 
 def get_js_sm(video_id):
@@ -412,7 +417,6 @@ def get_js_sm(video_id):
 
     watch_url = g.urls['watchv'] % video_id
     new.callback("Fetching watchv page")
-    dbg("Fetching watchv page")
     watchinfo = g.opener.open(watch_url).read().decode("utf8")
     dbg("Fetched watchv page")
     new.callback("Fetched watchv page")
@@ -428,6 +432,7 @@ def get_js_sm(video_id):
     if not funcs:
         new.callback("Fetching javascript")
         javascript = g.opener.open(js_url).read().decode("UTF-8")
+        dbg("Fetched javascript")
         new.callback("Fetched javascript")
         mainfunc = _get_mainfunc_from_js(javascript)
         funcs = _get_other_funcs(mainfunc, javascript)
@@ -441,7 +446,7 @@ def _get_matching_stream(smap, itag):
 
     for x in smap:
 
-        if x['itag'] == itag:
+        if x['itag'] == itag and x.get("s"):
             return x['url'], x['s']
 
     raise IOError("Sorry this video is not currently supported by pafy")
@@ -580,7 +585,7 @@ class Stream(object):
             # encrypted url signatures
 
             if self._parent.js_url:
-                dbg("using cached js %s" % self._parent.js_url[-15:])
+                #dbg("using cached js %s" % self._parent.js_url[-15:])
                 enc_streams = self._parent.enc_streams
 
             else:
@@ -675,12 +680,11 @@ class Pafy(object):
 
     """ Class to represent a YouTube video. """
 
-    funcmap = {}
+    funcmap = {}  # keep functions as a class variable
 
     def __init__(self, video_url, basic=True, gdata=False,
                  signature=True, size=False, callback=None):
 
-        dbg("funcmap size is %s", len(Pafy.funcmap))
         args = dict(basic=basic, gdata=gdata, signature=signature,
                     size=size, callback=callback, video_url=video_url)
 
@@ -747,7 +751,6 @@ class Pafy(object):
         if self._have_basic:
             return
 
-        new.callback("Fetching video info..")
         allinfo = get_video_info(self.videoid)
         new.callback("Fetched video info")
         f = lambda x: allinfo.get(x, ["unknown"])[0]
@@ -784,9 +787,7 @@ class Pafy(object):
         if self._have_gdata:
             return
 
-        new.callback("Fetching video data")
         gdata = get_video_gdata(self.videoid)
-        new.callback("Fetched video gdata")
         t0 = "{http://search.yahoo.com/mrss/}"
         t1 = "{http://www.w3.org/2005/Atom}"
         tree = ElementTree.fromstring(gdata)
